@@ -7,7 +7,7 @@ use Poe::Wheel::Run;
 
 use namespace::clean -except => 'meta';
 
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 
 with qw(
 	MooseX::Getopt
@@ -121,7 +121,7 @@ sub is_reachable {
 
 	$self->logger->debug("scutil -r $host: $out");
 
-	if ( $out =~ /^Reachable/ and not /Connection (?:Required|Automatic)/ ) {
+	if ( $out =~ /^Reachable/ and not $out =~ /Connection (?:Required|Automatic)/ ) {
 		$self->logger->debug("$host reachable");
 		return 1;
 	} else {
